@@ -140,6 +140,8 @@ TEST(MagneticSymmetry, test_spg_get_symmetry_with_site_tensors) {
     double(*translation)[3];
     int *spin_flips;
 
+    // 96  = 48 * 2
+    // = (max number of order of point group) * (spin degrees of freedom)
     max_size = num_atom * 96;
     rotation = (int(*)[3][3])malloc(sizeof(int[3][3]) * max_size);
     translation = (double(*)[3])malloc(sizeof(double[3]) * max_size);
@@ -314,8 +316,9 @@ TEST(MagneticSymmetry, test_spg_get_symmetry_with_tensors_rough_symprec) {
     int types[] = {0, 1, 1};
     double tensors[] = {0.005, 0.002, 0.002};
     int num_atoms = 3;
+    // 96  = 48 * 2
+    // = (max number of order of point group) * (spin degrees of freedom)
     int max_size = num_atoms * 96;
-
     double symprec = 1e-2;         // with high symprec
     double mag_symprec = symprec;  // with high mag_symprec
 
@@ -356,6 +359,29 @@ TEST(MagneticSymmetry, test_spg_get_symmetry_with_tensors_rough_symprec) {
     free(time_reversals);
 }
 
+TEST(MagneticSymmetry, test_spg_get_magnetic_dataset_high_mag_symprec) {
+    // https://github.com/spglib/spglib/issues/348
+    double lattice[3][3] = {{4, 0, 0}, {0, 4, 0}, {0, 0, 18}};
+    double positions[][3] = {
+        {0, 0, 0.57},
+        {0.5, 0.5, 0.43},
+        {0.5, 1, 0.5},
+        {0, 0.5, 0.5},
+    };
+    int types[] = {1, 1, 2, 2};
+    double tensors[] = {0, 0, -1, 1};
+    int num_atoms = 4;
+    double symprec = 3.0;
+
+    auto dataset = spg_get_magnetic_dataset(lattice, positions, types, tensors,
+                                            0, num_atoms, 0, symprec);
+    // MSG identification is failed with the too high mag_symprec
+    EXPECT_EQ(dataset, nullptr);
+
+    auto error = spg_get_error_code();
+    EXPECT_EQ(error, SpglibError::SPGERR_ATOMS_TOO_CLOSE);
+}
+
 TEST(MagneticSymmetry, test_spgms_get_magnetic_dataset_high_mag_symprec) {
     // https://github.com/spglib/spglib/issues/249
     double lattice[3][3] = {
@@ -379,14 +405,14 @@ TEST(MagneticSymmetry, test_spgms_get_magnetic_dataset_high_mag_symprec) {
         0.00000000,  -0.00000000, -0.02900000,
     };
     int num_atoms = 6;
-
+    // 96  = 48 * 2
+    // = (max number of order of point group) * (spin degrees of freedom)
     int max_size = num_atoms * 96;
-
     double symprec = 1e-5;
     double mag_symprec = 1e-1;  // with high mag_symprec
 
     int size;
-    int equivalent_atoms[3];
+    int equivalent_atoms[6];
     double primitive_lattice[3][3];
     int(*rotations)[3][3];
     double(*translations)[3];
@@ -421,6 +447,61 @@ TEST(MagneticSymmetry, test_spgms_get_magnetic_dataset_high_mag_symprec) {
     if (dataset != NULL) spg_free_magnetic_dataset(dataset);
 }
 
+TEST(MagneticSymmetry, test_spg_get_magnetic_dataset_non_collinear) {
+    double lattice[3][3] = {{10, 0, 0}, {0, 10, 0}, {0, 0, 10}};
+    double position[][3] = {
+        {0, 0, 0},
+    };
+    int types[] = {1};
+    double spins[3] = {1, 0, 0};
+    int num_atom = 1;
+    SpglibMagneticDataset *dataset;
+    dataset = spg_get_magnetic_dataset(lattice, position, types, spins, 1,
+                                       num_atom, 1, 1e-5);
+
+    ASSERT_NE(dataset, nullptr);
+    EXPECT_EQ(dataset->n_operations, 16);
+    if (HasFailure()) show_spg_magnetic_dataset(dataset);
+    spg_free_magnetic_dataset(dataset);
+}
+
+TEST(MagneticSymmetry, test_spg_get_symmetry_with_site_tensors_non_collinear) {
+    double lattice[3][3] = {{10, 0, 0}, {0, 10, 0}, {0, 0, 10}};
+    double position[][3] = {
+        {0, 0, 0},
+    };
+    int types[] = {1};
+    double tensors[3] = {1, 0, 0};
+    int num_atoms = 1;
+    // 96  = 48 * 2
+    // = (max number of order of point group) * (spin degrees of freedom)
+    int max_size = num_atoms * 96;
+
+    int size;
+    int equivalent_atoms[1];
+    double primitive_lattice[3][3];
+    int(*rotations)[3][3];
+    double(*translations)[3];
+    int *spin_flips;
+    int *time_reversals;
+
+    rotations = (int(*)[3][3])malloc(sizeof(int[3][3]) * max_size);
+    translations = (double(*)[3])malloc(sizeof(double[3]) * max_size);
+    spin_flips = (int *)malloc(sizeof(int *) * max_size);
+    time_reversals = (int *)malloc(sizeof(int *) * max_size);
+
+    size = spg_get_symmetry_with_site_tensors(
+        rotations, translations, equivalent_atoms, primitive_lattice,
+        spin_flips, max_size, lattice, position, types, tensors, 1, num_atoms,
+        1 /* with_time_reversal */, 1 /* is_axial */, 1e-5);
+
+    ASSERT_TRUE(size == 16);
+    free(rotations);
+    free(translations);
+    free(spin_flips);
+    free(time_reversals);
+}
+
 TEST(MagneticSymmetry, test_with_broken_symmetry) {
     // https://github.com/spglib/spglib/issues/194
     // Part of "mp-806965" in the Materials Project database
@@ -439,6 +520,8 @@ TEST(MagneticSymmetry, test_with_broken_symmetry) {
     int types[] = {0, 0, 0, 0};
     double tensors[] = {1.927, 1.947, 1.928, 1.949};
     int num_atoms = 4;
+    // 96  = 48 * 2
+    // = (max number of order of point group) * (spin degrees of freedom)
     int max_size = num_atoms * 96;
 
     double symprec = 0.1;  // with very high symprec
